# Getting started

::::{grid} 2

:::{grid-item-card} {octicon}`desktop-download;1em`&nbsp; Installation
:link: installation.md

:::

:::{grid-item-card} {octicon}`eye;1em`&nbsp; Overview
:link: overview.ipynb

:::

::::

::::{grid} 2

:::{grid-item-card} {octicon}`graph;1em`&nbsp; Numpy, Pandas, and Xarray
:link: numpy-pandas-xarray.ipynb

:::

:::{grid-item-card} {octicon}`download;1em`&nbsp; Saving figures to disk
:link: saving-figures.ipynb

:::

::::

```{toctree}
---
hidden:
---

installation
overview
numpy-pandas-xarray
saving-figures
```